==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d5/de1/win32__v_8cpp.js <==
var win32__v_8cpp =
[
    [ "VkMapping", "db/d73/structVkMapping.html", "db/d73/structVkMapping" ],
    [ "AM", "d5/de1/win32__v_8cpp.html#a522071f391a5eced6ca3d88b3496a7c1", null ],
    [ "AS", "d5/de1/win32__v_8cpp.html#ac2c71e01479b0b511b71905fe0ce49de", null ],
    [ "GET_WHEEL_DELTA_WPARAM", "d5/de1/win32__v_8cpp.html#aa094732c1d6d4fbe4f1b0d81486babb0", null ],
    [ "MAPVK_VK_TO_CHAR", "d5/de1/win32__v_8cpp.html#ab68db5529d5737535154b009a89e9559", null ],
    [ "MOUSE_POLL_DELAY", "d5/de1/win32__v_8cpp.html#afcd0147e98ecab23b2c51213b37e0096", null ],
    [ "PM_QS_INPUT", "d5/de1/win32__v_8cpp.html#a1429afa0eaa3fcc452ebc0037dd0c09f", null ],
    [ "TID_POLLMOUSE", "d5/de1/win32__v_8cpp.html#aa386685eedb07a5d59c703cf4ce71e3c", null ],
    [ "WM_MOUSELEAVE", "d5/de1/win32__v_8cpp.html#aa2fd2e3781607c91ab72afd2cce044fd", null ],
    [ "WM_MOUSEWHEEL", "d5/de1/win32__v_8cpp.html#a9d3b2a3f4572e6ec9d3ce57fec9d8083", null ],
    [ "PFNTRACKMOUSEEVENT", "d5/de1/win32__v_8cpp.html#ac5f72db546a0f80e9a20c04a05750a37", null ],
    [ "AllocateDibSection", "d5/de1/win32__v_8cpp.html#a940f7b8c97ee211dafa3cacd9dccf3fb", null ],
    [ "CancelIMEComposition", "d5/de1/win32__v_8cpp.html#ad8a1ac08df65238ae8d9928068839ae3", null ],
    [ "CheckPaletteAnim", "d5/de1/win32__v_8cpp.html#ac2bbc0961c64af34880dbdf7b4b824d5", null ],
    [ "ClientSizeChanged", "d5/de1/win32__v_8cpp.html#acf228bfb846141fe761d21c7d8d42973", null ],
    [ "DrawIMECompositionString", "d5/de1/win32__v_8cpp.html#a57561c4d8aefd6dd37d5923befdeb7b4", null ],
    [ "FindResolutions", "d5/de1/win32__v_8cpp.html#a703acb34bad1479a06d9d8c809e6308b", null ],
    [ "HandleCharMsg", "d5/de1/win32__v_8cpp.html#a230a41df14cf05fd4aabe0fe615f8842", null ],
    [ "HandleIMEComposition", "d5/de1/win32__v_8cpp.html#a666ab14e97fe061fc521fc3bc5d822a0", null ],
    [ "MakePalette", "d5/de1/win32__v_8cpp.html#a7b8ed727520e99e0a19df1a8c573e36e", null ],
    [ "MapWindowsKey", "d5/de1/win32__v_8cpp.html#a47c52f7f02b00e60f89193a83c09ea91", null ],
    [ "PaintWindow", "d5/de1/win32__v_8cpp.html#aa9514ee9c44cade2f0d3ceec847321ab", null ],
    [ "PaintWindowThread", "d5/de1/win32__v_8cpp.html#a4f73d4f0eed2c60e16365fac8ce34474", null ],
    [ "RegisterWndClass", "d5/de1/win32__v_8cpp.html#ab9d12a4de2adc2757bddceb1d00fa545", null ],
    [ "SetCandidatePos", "d5/de1/win32__v_8cpp.html#a95e7578ebf90533a9485db5d796a91b6", null ],
    [ "SetCompositionPos", "d5/de1/win32__v_8cpp.html#adeccfcc88457bef168df29ba330e36a4", null ],
    [ "TrackMouseTimerProc", "d5/de1/win32__v_8cpp.html#a0853a4d60049946b74efd97258b1f152", null ],
    [ "UpdatePalette", "d5/de1/win32__v_8cpp.html#a43d8f47a1a73270d3e3e18e6cc945b50", null ],
    [ "WndProcGdi", "d5/de1/win32__v_8cpp.html#a7fef989a1ac75956527ebfff4c2d458a", null ],
    [ "_bck_resolution", "d5/de1/win32__v_8cpp.html#a6bed3a38c7af42439e8933860d23f2a0", null ],
    [ "_display_hz", "d5/de1/win32__v_8cpp.html#a1051bf3d4f4ea731ab874d3dfa27d48e", null ],
    [ "_draw_continue", "d5/de1/win32__v_8cpp.html#a83b7c91807a94e09901c50386a6ca90c", null ],
    [ "_draw_mutex", "d5/de1/win32__v_8cpp.html#a53b7002dbbd95a5d36d58908f35e2055", null ],
    [ "_draw_thread", "d5/de1/win32__v_8cpp.html#a5b88b5bb0b2e5c390c2cfbc73b525c81", null ],
    [ "_draw_thread_initialized", "d5/de1/win32__v_8cpp.html#a951c6b6e2daa0f033f26821e06f93843", null ],
    [ "_draw_threaded", "d5/de1/win32__v_8cpp.html#ac44f053e1e70a94bbe88cf6f973a3095", null ],
    [ "_force_full_redraw", "d5/de1/win32__v_8cpp.html#af696bbbd66e44d62708a52d6e22f8883", null ],
    [ "_imm_props", "d5/de1/win32__v_8cpp.html#a1a645f2907be94c4a0751298d79f290e", null ],
    [ "_local_palette", "d5/de1/win32__v_8cpp.html#a202ff6c8b1a11ccdc59df0dba543cdd5", null ],
    [ "_pTrackMouseEvent", "d5/de1/win32__v_8cpp.html#a4cea4c5a5b26716bc30413c699c2f00c", null ],
    [ "_vk_mapping", "d5/de1/win32__v_8cpp.html#aaa6910b0fdef2ce9c5578cba4112f711", null ],
    [ "_window_maximize", "d5/de1/win32__v_8cpp.html#aafa29032f8d534111611abad3f09dd5e", null ],
    [ "_wnd", "d5/de1/win32__v_8cpp.html#a2e366e5c5970e732a9eb2edd41024977", null ],
    [ "buffer_bits", "d5/de1/win32__v_8cpp.html#aedcb17f667580adc4afce5cad91808bb", null ],
    [ "default_resolutions", "d5/de1/win32__v_8cpp.html#aba4774a8da5c846e23b5eec4295502ef", null ],
    [ "dib_sect", "d5/de1/win32__v_8cpp.html#a371adc05ad746115226578eaf1a3e47e", null ],
    [ "fullscreen", "d5/de1/win32__v_8cpp.html#a5a9147cb82d1cbeefadd62beb9e6910b", null ],
    [ "gdi_palette", "d5/de1/win32__v_8cpp.html#a277516579cdd7668cdde124489a64dd5", null ],
    [ "has_focus", "d5/de1/win32__v_8cpp.html#adeee2fe45d1a1746ef0959ffe6957234", null ],
    [ "height", "d5/de1/win32__v_8cpp.html#ad12fc34ce789bce6c8a05d8a17138534", null ],
    [ "height_org", "d5/de1/win32__v_8cpp.html#ae22caa36ee8c1d7eda9f6ec388fa0ff9", null ],
    [ "iFVideoDriver_Win32", "d5/de1/win32__v_8cpp.html#ae390abbf49447443403017c9dbe4acae", null ],
    [ "main_wnd", "d5/de1/win32__v_8cpp.html#a9b67d5c80fd77e5261877c17fc2cb6df", null ],
    [ "running", "d5/de1/win32__v_8cpp.html#a36f7b6be7108281af77939ceaec42fd6", null ],
    [ "update_rect", "d5/de1/win32__v_8cpp.html#a4385c5007b7dfdbd4574f88cc2f0f413", null ],
    [ "width", "d5/de1/win32__v_8cpp.html#a2474a5474cbff19523a51eb1de01cda4", null ],
    [ "width_org", "d5/de1/win32__v_8cpp.html#a71b00be0f86d92764c2bdd053aa2c45d", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d5/de1/win32__v_8cpp.js <==
var win32__v_8cpp =
[
    [ "VkMapping", "db/d73/structVkMapping.html", "db/d73/structVkMapping" ],
    [ "AM", "d5/de1/win32__v_8cpp.html#a522071f391a5eced6ca3d88b3496a7c1", null ],
    [ "AS", "d5/de1/win32__v_8cpp.html#ac2c71e01479b0b511b71905fe0ce49de", null ],
    [ "GET_WHEEL_DELTA_WPARAM", "d5/de1/win32__v_8cpp.html#aa094732c1d6d4fbe4f1b0d81486babb0", null ],
    [ "MAPVK_VK_TO_CHAR", "d5/de1/win32__v_8cpp.html#ab68db5529d5737535154b009a89e9559", null ],
    [ "PM_QS_INPUT", "d5/de1/win32__v_8cpp.html#a1429afa0eaa3fcc452ebc0037dd0c09f", null ],
    [ "WM_MOUSEWHEEL", "d5/de1/win32__v_8cpp.html#a9d3b2a3f4572e6ec9d3ce57fec9d8083", null ],
    [ "AllocateDibSection", "d5/de1/win32__v_8cpp.html#a940f7b8c97ee211dafa3cacd9dccf3fb", null ],
    [ "CancelIMEComposition", "d5/de1/win32__v_8cpp.html#ad8a1ac08df65238ae8d9928068839ae3", null ],
    [ "CheckPaletteAnim", "d5/de1/win32__v_8cpp.html#ac2bbc0961c64af34880dbdf7b4b824d5", null ],
    [ "ClientSizeChanged", "d5/de1/win32__v_8cpp.html#acf228bfb846141fe761d21c7d8d42973", null ],
    [ "DrawIMECompositionString", "d5/de1/win32__v_8cpp.html#a57561c4d8aefd6dd37d5923befdeb7b4", null ],
    [ "FindResolutions", "d5/de1/win32__v_8cpp.html#a703acb34bad1479a06d9d8c809e6308b", null ],
    [ "HandleCharMsg", "d5/de1/win32__v_8cpp.html#a230a41df14cf05fd4aabe0fe615f8842", null ],
    [ "HandleIMEComposition", "d5/de1/win32__v_8cpp.html#a666ab14e97fe061fc521fc3bc5d822a0", null ],
    [ "MakePalette", "d5/de1/win32__v_8cpp.html#a7b8ed727520e99e0a19df1a8c573e36e", null ],
    [ "MapWindowsKey", "d5/de1/win32__v_8cpp.html#a47c52f7f02b00e60f89193a83c09ea91", null ],
    [ "PaintWindow", "d5/de1/win32__v_8cpp.html#aa9514ee9c44cade2f0d3ceec847321ab", null ],
    [ "PaintWindowThread", "d5/de1/win32__v_8cpp.html#a26cadf145bf3cc466a7498eb5f69cc19", null ],
    [ "RegisterWndClass", "d5/de1/win32__v_8cpp.html#ab9d12a4de2adc2757bddceb1d00fa545", null ],
    [ "SetCandidatePos", "d5/de1/win32__v_8cpp.html#a95e7578ebf90533a9485db5d796a91b6", null ],
    [ "SetCompositionPos", "d5/de1/win32__v_8cpp.html#adeccfcc88457bef168df29ba330e36a4", null ],
    [ "UpdatePalette", "d5/de1/win32__v_8cpp.html#a43d8f47a1a73270d3e3e18e6cc945b50", null ],
    [ "WndProcGdi", "d5/de1/win32__v_8cpp.html#a7fef989a1ac75956527ebfff4c2d458a", null ],
    [ "_bck_resolution", "d5/de1/win32__v_8cpp.html#a6bed3a38c7af42439e8933860d23f2a0", null ],
    [ "_display_hz", "d5/de1/win32__v_8cpp.html#a1051bf3d4f4ea731ab874d3dfa27d48e", null ],
    [ "_draw_continue", "d5/de1/win32__v_8cpp.html#a83b7c91807a94e09901c50386a6ca90c", null ],
    [ "_draw_mutex", "d5/de1/win32__v_8cpp.html#af24370c5565125ce208ff861eec76e30", null ],
    [ "_draw_signal", "d5/de1/win32__v_8cpp.html#ac92b66b6cc9dc668f406c1a608e5af68", null ],
    [ "_draw_threaded", "d5/de1/win32__v_8cpp.html#ac44f053e1e70a94bbe88cf6f973a3095", null ],
    [ "_force_full_redraw", "d5/de1/win32__v_8cpp.html#af696bbbd66e44d62708a52d6e22f8883", null ],
    [ "_imm_props", "d5/de1/win32__v_8cpp.html#a1a645f2907be94c4a0751298d79f290e", null ],
    [ "_local_palette", "d5/de1/win32__v_8cpp.html#a202ff6c8b1a11ccdc59df0dba543cdd5", null ],
    [ "_vk_mapping", "d5/de1/win32__v_8cpp.html#aaa6910b0fdef2ce9c5578cba4112f711", null ],
    [ "_window_maximize", "d5/de1/win32__v_8cpp.html#aafa29032f8d534111611abad3f09dd5e", null ],
    [ "_wnd", "d5/de1/win32__v_8cpp.html#a1e562f0ded25c8cc8076e1f257646359", null ],
    [ "buffer_bits", "d5/de1/win32__v_8cpp.html#aedcb17f667580adc4afce5cad91808bb", null ],
    [ "default_resolutions", "d5/de1/win32__v_8cpp.html#aba4774a8da5c846e23b5eec4295502ef", null ],
    [ "dib_sect", "d5/de1/win32__v_8cpp.html#a371adc05ad746115226578eaf1a3e47e", null ],
    [ "fullscreen", "d5/de1/win32__v_8cpp.html#a5a9147cb82d1cbeefadd62beb9e6910b", null ],
    [ "gdi_palette", "d5/de1/win32__v_8cpp.html#a277516579cdd7668cdde124489a64dd5", null ],
    [ "has_focus", "d5/de1/win32__v_8cpp.html#adeee2fe45d1a1746ef0959ffe6957234", null ],
    [ "height", "d5/de1/win32__v_8cpp.html#ad12fc34ce789bce6c8a05d8a17138534", null ],
    [ "height_org", "d5/de1/win32__v_8cpp.html#ae22caa36ee8c1d7eda9f6ec388fa0ff9", null ],
    [ "iFVideoDriver_Win32", "d5/de1/win32__v_8cpp.html#ae390abbf49447443403017c9dbe4acae", null ],
    [ "main_wnd", "d5/de1/win32__v_8cpp.html#a9b67d5c80fd77e5261877c17fc2cb6df", null ],
    [ "running", "d5/de1/win32__v_8cpp.html#a36f7b6be7108281af77939ceaec42fd6", null ],
    [ "update_rect", "d5/de1/win32__v_8cpp.html#a4385c5007b7dfdbd4574f88cc2f0f413", null ],
    [ "width", "d5/de1/win32__v_8cpp.html#a2474a5474cbff19523a51eb1de01cda4", null ],
    [ "width_org", "d5/de1/win32__v_8cpp.html#a71b00be0f86d92764c2bdd053aa2c45d", null ]
];
